==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/tests/event/observer/transactional/custom/GiraffeService.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.event.observer.transactional.custom;

import javax.annotation.Resource;
import javax.ejb.Stateless;
import javax.ejb.TransactionManagement;
import javax.ejb.TransactionManagementType;
import javax.enterprise.event.Event;
import javax.inject.Inject;
import javax.transaction.UserTransaction;

import org.jboss.cdi.tck.util.ActionSequence;

@Stateless
@TransactionManagement(TransactionManagementType.BEAN)
public class GiraffeService {

    @Inject
    private Event<Giraffe> event;

    @Resource
    private UserTransaction userTransaction;

    public void feed() throws Exception {
        userTransaction.begin();
        event.fire(new Giraffe());
        ActionSequence.addAction("checkpoint");
        userTransaction.commit();
    }

}

==> cdi-tck-4.0.13-dist.zip: org/jboss/cdi/tck/tests/event/observer/transactional/custom/GiraffeService.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.event.observer.transactional.custom;

import jakarta.annotation.Resource;
import jakarta.ejb.Stateless;
import jakarta.ejb.TransactionManagement;
import jakarta.ejb.TransactionManagementType;
import jakarta.enterprise.event.Event;
import jakarta.inject.Inject;
import jakarta.transaction.UserTransaction;

import org.jboss.cdi.tck.util.ActionSequence;

@Stateless
@TransactionManagement(TransactionManagementType.BEAN)
public class GiraffeService {

    @Inject
    private Event<Giraffe> event;

    @Resource
    private UserTransaction userTransaction;

    public void feed() throws Exception {
        userTransaction.begin();
        event.fire(new Giraffe());
        ActionSequence.addAction("checkpoint");
        userTransaction.commit();
    }

}
